/**
 * Create a new `Ti.UI.TabGroup`.
 */
var tabGroup = Ti.UI.createTabGroup();

/**
 * Add the two created tabs to the tabGroup object.
 */
tabGroup.addTab(createTab("Home", "I am Window 1", "assets/images/icon-home-solid.png"));
tabGroup.addTab(createTab("Contact", "I am Window 2", "assets/images/icon-home-hover.png"));

/**
 * Open the tabGroup
 */
tabGroup.open();

/**
 * Creates a new Tab and configures it.
 *
 * @param  {String} title The title used in the `Ti.UI.Tab` and it's included `Ti.UI.Window`
 * @param  {String} message The title displayed in the `Ti.UI.Label`
 * @return {String} icon The icon used in the `Ti.UI.Tab`
 */
function createTab(title, message, icon) {
    var win = Ti.UI.createWindow({
        title: title,
        backgroundColor: '#fff'
    });

    var label = Ti.UI.createLabel({
        text: message,
        color: "#333",
        font: {
            fontSize: 20
        }
    });

    win.add(label);

    var tab = Ti.UI.createTab({
        title: title,
        icon: icon,
        window: win,
        
        // Use the "iconInsets" property to center the image if no title is provided. 
        // Comment the following property out if you do not (!) use a title and
        // read more here: 
        //   - http://www.appcelerator.com/blog/2016/03/titanium-5-2-0-wrap-up-of-new-features-for-ios/#tab-icon-insets
        //   - https://github.com/appcelerator-developer-relations/appc-sample-ti520/blob/master/app/styles/tab.tss
        //   - http://docs.appcelerator.com/platform/latest/#!/api/Titanium.UI.Tab-property-iconInsets
        // iconInsets: {
        //   top: 5
        // }
        
        // Uncomment the following to use a different icon when the tab is selected
        // and read more here: http://docs.appcelerator.com/platform/latest/#!/api/Titanium.UI.Tab-property-activeIcon
        // selectedIcon: 'assets/images/home.png'
    });

    return tab;
}
